<#  
.SYNOPSIS  
    Sets redirection from root and forces SSL settings

.DESCRIPTION  
    Redirects / to /owa and forces SSL on recommended vdirs
    Configures rights on web.config file for OAB

.NOTES  
    Version      				: 1.2 - See changelog at http://www.ehloworld.com/608
    Rights Req'd 				: Local Server Admin
    Sch Task Req 				: No
    Exchange Ver 				: 2010
    Author       				: Pat Richard, Exchange MVP
   	Email/Blog/Twitter	: pat@innervation.com 	http://www.ehloworld.com @patrichard
    Blog         				: http://www.ehloworld.com/186
    Disclaimer   				: Don't blame me if this breaks your stuff.
    Info Stolen  				: http://blogs.msexchange.org/walther/2010/03/22/oab-issues-after-simplifying-the-owa-2010-url/

.LINK  
	http://www.ehloworld.com/186

.EXAMPLE
	.\Set-Exchange2010RedirectSSL.ps1 -url "https://mail.ehloworld.com/owa"

.INPUTS
	None. You cannot pipe objects to this script.

.PARAMETER URL
    Specifies the destination to redirect to

.PARAMETER ForceSSL
		Whether the Exchange specific virtual directories are set to require SSL. Default is $True
#>
#Requires -Version 2.0

param(
	[Parameter(ValueFromPipeline=$true, ValueFromPipelineByPropertyName=$true, Mandatory=$false, HelpMessage="Please specify a URL to redirect to.")]
	[string]$url,
	[Parameter(ValueFromPipeline=$true, ValueFromPipelineByPropertyName=$true, Mandatory=$false)]
	[string]$ForceSSL,
	[Parameter(ValueFromPipeline=$false, ValueFromPipelineByPropertyName=$false, Mandatory=$false)]
	[string]$SetupRegistryPath,
	[Parameter(ValueFromPipeline=$false, ValueFromPipelineByPropertyName=$false, Mandatory=$false)]
	[string]$SetupEntries,
	[Parameter(ValueFromPipeline=$false, ValueFromPipelineByPropertyName=$false, Mandatory=$false)]
	[string]$InstallPath,
	[Parameter(ValueFromPipeline=$false, ValueFromPipelineByPropertyName=$false, Mandatory=$false)]
	[string]$PathToFile,
	[Parameter(ValueFromPipeline=$true, ValueFromPipelineByPropertyName=$true, Mandatory=$false)]
	[string]$backup
) #end param

function Get-ModuleStatus { 
	param	(
		[parameter(ValueFromPipeline=$true, ValueFromPipelineByPropertyName=$true, Mandatory=$true, HelpMessage="No module name specified!")] 
		[string]$name
	)
	if(!(Get-Module -name "$name")) { 
		if(Get-Module -ListAvailable | ? {$_.name -eq "$name"}) { 
			Import-Module -Name "$name" 
			# module was imported
			return $true
		} else {
			# module was not available
			return $false
		}
	}else {
		# module was already imported
		# Write-Host "$name module already imported"
		return $true
	}
} # end function Get-ModuleStatus

function Get-ExchangeInstallPath	{
    # Get the root setup entries.
    $setupRegistryPath = "HKLM:\SOFTWARE\Microsoft\ExchangeServer\v14\Setup"
    $setupEntries = Get-ItemProperty $setupRegistryPath
    if($setupEntries -eq $null) {
        return $null
    }

    # Try to get the Install Path.
    $InstallPath = $setupEntries.MsiInstallPath
    return $InstallPath
} # end function GetExchangeInstallPath

Get-ModuleStatus ServerManager

if ((Get-WindowsFeature web-http-redirect).installed -eq $false){
	Write-Host "`nInstalling web-http-redirect feature" -ForegroundColor green
	Add-WindowsFeature web-http-redirect
}

$PathToFile = (Get-ExchangeInstallPath)+"ClientAccess\OAB\web.config"
pushd
Set-Location "c:\Windows\System32\inetsrv"
Write-Host "Backing up current IIS configuration" -ForegroundColor green
$backup = "OWA Redirect Backup "+(get-date -format "MMddyyyy-hhmmss")
.\appcmd.exe ADD Backup $backup

Write-Host "`nConfiguring redirection to $url" -ForegroundColor green
.\appcmd set config "Default Web Site" /section:httpRedirect /childonly:true /enabled:true /destination:"$url"
.\appcmd set config "Default Web Site/Aspnet_Client" /section:httpRedirect /enabled:false
.\appcmd set config "Default Web Site/Autodiscover" /section:httpRedirect /enabled:false
.\appcmd set config "Default Web Site/ECP" /section:httpRedirect /enabled:false
.\appcmd set config "Default Web Site/EWS" /section:httpRedirect /enabled:false
.\appcmd set config "Default Web Site/Microsoft-Server-ActiveSync" /section:httpRedirect /enabled:false
.\appcmd set config "default web site/OAB" /section:httpRedirect /enabled:false
.\appcmd set config "Default Web Site/PowerShell" /section:httpRedirect /enabled:false
.\appcmd set config "Default Web Site/Rpc" /section:httpRedirect /enabled:false

if ($ForceSSL -ne $false){
	Write-Host "`nSetting SSL configuration" -ForegroundColor green
	.\appcmd set config "Default Web Site" /section:access /sslFlags:"" /commit:apphost
	.\appcmd set config "Default Web Site/Aspnet_Client" /section:access /sslFlags:"Ssl,Ssl128" /commit:apphost
	.\appcmd set config "Default Web Site/Autodiscover" /section:access /sslFlags:"Ssl,Ssl128" /commit:apphost
	.\appcmd set config "Default Web Site/ECP" /section:access /sslFlags:"Ssl,Ssl128" /commit:apphost
	.\appcmd set config "Default Web Site/EWS" /section:access /sslFlags:"Ssl,Ssl128" /commit:apphost
	.\appcmd set config "Default Web Site/Exchange" /section:access /sslFlags:"Ssl,Ssl128" /commit:apphost
	.\appcmd set config "Default Web Site/Exchweb" /section:access /sslFlags:"Ssl,Ssl128" /commit:apphost
	.\appcmd set config "Default Web Site/Microsoft-Server-ActiveSync" /section:access /sslFlags:"Ssl,Ssl128" /commit:apphost
	.\appcmd set config "default web site/OAB" /section:access /sslFlags:"" /commit:apphost
	.\appcmd set config "Default Web Site/OWA" /section:access /sslFlags:"Ssl,Ssl128" /commit:apphost
	.\appcmd set config "default web site/PowerShell" /section:access /sslFlags:"" /commit:apphost
	.\appcmd set config "Default Web Site/Public" /section:access /sslFlags:"Ssl,Ssl128" /commit:apphost
	.\appcmd set config "Default Web Site/Rpc" /section:access /sslFlags:Ssl /commit:apphost
	.\appcmd set config "Default Web Site/RpcWithCert" /section:access /sslFlags:"Ssl,Ssl128" /commit:apphost
}

if (Test-Path($PathToFile)){
	icacls $PathToFile /grant:R 'NT Authority\Authenticated Users:R'
}

Write-Host "`nRestarting IIS for configuration to take effect" -ForegroundColor green
iisreset
Write-Host "`nDone!" -ForegroundColor green
popd